@@ -23,7 +23,7 @@ class User():
 			if name == "query":
 				self.query = value
 		try:
-			self.UserObject = HTTPRequest(f"users/search", 'get', params = {"from": self.platform, "query": self.query})
+			self.UserObject = HTTPRequest(f"users/search?from={self.platform}&query={self.query}", 'get')
 		except:
 			raise ValueError("Missing 'platform' or 'query' keyword argument.")
 
