@@ -4,21 +4,26 @@ import json
 def get_url(API):
 	return f"https://api.meaxisnetwork.net/v3/{API}"
 
-def HTTPRequest(API, method, **kwargs):
+def HTTPRequest(API, method, params = {}, data = {}, cookies = {}):
 	'''
 	Sends a HTTP Request through the MeaxisNetwork API.
 	'''
-	cookies = {}
-	params = {}
-	data = {}
-
-	for key, value in kwargs.items():
-		vars()[key] = value
-
+	cookies = cookies
+	params = params
+	data = data
 
 	URL = get_url(API)
+	PARAMS = 0
 
-	return vars(requests)[method](URL, params = params, data = data, cookies = cookies)
+	for key, value in params.items():
+		if PARAMS == 0:
+			URL = URL + "?" + key + "=" + value
+			PARAMS += 1
+		else:
+			URL = URL + "&" + key + "=" + value
+			PARAMS += 1
+
+	return vars(requests)[method](URL, data = data, cookies = cookies)
 
 
 def check_response(Response):
@@ -28,4 +33,4 @@ def check_response(Response):
 		error_data = {"error_message": response_text.replace('"', ''), "http_status_code": Response.status_code, "documentation_reference": f"https://meaxisnetwork.net/create/docs/api/error-codes#{error_code}", "error_code": error_code}
 		return json.dumps(error_data, indent = 2)
 	else:
-		return True
\ No newline at end of file
+		return True
