@@ -1,6 +1,5 @@
 import requests
 import json
-from .utils import check_response
 
 class Funfact():
 	def __init__(self):
@@ -19,5 +18,4 @@ class Funfact():
 			self.id = FunfactJSON["id"]
 			self.funfact = FunfactJSON["text"]
 		except:
-			ErrorResponse = check_response(self.FunfactObject)
-			raise ValueError(ErrorResponse)
\ No newline at end of file
+			pass
\ No newline at end of file
